
#Build ROC curve and get AUC values 

# clear workspace
rm(list=ls())

#Load packages
library(ROCR)
library(maptools)
library(foreach)

#set working directory

setwd("~/Filzbach Examples/workspace")
# 2015 run now under deforestation_no_province_no_lc


#Import observed deforestation (make sure to change this according to the model being validated, for example 2008-2010 model, should be obs2010)

def<-as.matrix(readAsciiGrid("deforestation_2012_16_repro_res.ascii"))

def<-c(def)

#Change NA's to zeros
def<-ifelse(is.na(def),0,def)

#Import predicted probabilities from Ascii grids
iterations<- 100
auc.values<- foreach(i = 1:iterations, .combine = rbind)%do%{
	print(i)
 
	fitted.values<-as.matrix(readAsciiGrid(paste("predprob_yr0_i",i-1,".asc",sep="")))
	fitted.values<-c(fitted.values)

	#Create data matrix
	data<-cbind(def,fitted.values)

	#New vector of predicted and observed
	newdef<-data[,1]
	newfit<-data[,2]

	#Calculating goodness of fit measure (AUC):
	pred<-prediction(newfit,newdef)
	auc.data<-performance(pred,"auc")
	auc.model<-slot(auc.data, "y.values")
return(auc.model)
}

auc.values<-as.numeric(auc.values)

#Export values
write.csv(auc.values,"aucallvalues_2012_16_with_2012_16.csv")

# plot histogram of AUC values
pdf("auc_hist_2012_16_with_2012_16.pdf")
hist(auc.values)
dev.off()


