# Script to output the cumulative deforestation probability  

# clear workspace
rm(list=ls())


#Load packages
library(maptools)

crs_aea <- "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0
  +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" # final projection


#set working directory
setwd("~/Filzbach Examples/workspace")

#Get the coordinates of each pixel (Spatial Points):
data<-readAsciiGrid("predfor_i0_0yr.asc")
spatial.points<-as.data.frame(SpatialPoints(data))
data.mat<-as.matrix(data)

sum.prob<-ifelse(is.na(data.mat),-9999,0)

#Load probability maps from 2010 to 2050
for(i in 0:3){

#print(paste("Starting year ",2010+i*2,sep=""))  #here is just to print the correct year! 

data2<-as.matrix(readAsciiGrid(paste("probdefyear",i,".asc",sep="")))
newdata<-ifelse(is.na(data2),0,data2)

sum.prob<-sum.prob+newdata

sum.prob2<-ifelse(sum.prob<0,-9999,sum.prob)

#Get vector
sum.vec<-c(sum.prob2)

#Export ascii map
print("Exporting final map in .ASC")
out<-data.frame(sum.vec,spatial.points)
coordinates(out)=~s1+s2
gridded(out)=TRUE
out.grid<-as(out,"SpatialGridDataFrame")


writeAsciiGrid(out.grid,paste("sumprob",paste0(2012+(i*5), "_", 2012+(i*5+4)),".asc",sep=""),attr=1,na.value=-9999) #here is just to output the cumulative map with the correct year! 

}




