rm(list = ls())
library(tidyverse)
library(reshape2)
# Script to plot the rates of deforestation 
#set working directory
setwd("~/Filzbach Examples/workspace")

options(scipen=999)

data<-read.table("Model_50yrs.txt",header=T)
attach(data)
names(data)


jpeg("DefRate.jpg",res=100,height=720,width=1024)
boxplot(RateDef[RateDef>=0]~Year[RateDef>=0], data= data,xlab="Year",ylab="Annual Deforestation Rate (%)")
boxplot(RateDef[RateDef>=0]~Year[RateDef>=0], data= data[data$Year < 8, ],xlab="Year",ylab="Annual Deforestation Rate (%)")
dev.off()

jpeg("DefTot.jpg",res=100,height=720,width=1024)
boxplot(TotalDef[TotalDef>=0]~Year[TotalDef>=0], data = data, xlab="Year",ylab="Annual Deforestation (1x1km)")
boxplot(TotalDef[TotalDef>=0]~Year[TotalDef>=0], data =data[data$Year < 8, ], xlab="Year",ylab="Annual Deforestation (1x1km)")
dev.off()

jpeg("ForLeft.jpg",res=100,height=720,width=1024)
boxplot(ForestLeft[ForestLeft>=0]~Year[ForestLeft>=0],data = data, xlab="Year",ylab="Remaining Forest (1x1km)")
boxplot(ForestLeft[ForestLeft>=0]~Year[ForestLeft>=0],data = data[data$Year < 8, ], xlab="Year",ylab="Remaining Forest (1x1km)")
dev.off()


# Script to plot the Parameter Values
parameters<-read.table("Parameters_Values.txt",header=T)
attach(parameters)
names(parameters)




lookup_names <- data.frame(variable = c(paste0("beta_", 0:6), 
                                        paste0("gamlu_", 0:5)), 
                           name = 
                      c("intercept", "previous tree cover loss","distance to roads",
                        "distance to rivers","density of fire", "topography", "population density",
                    "PA 1-3 (IUCN)*", "PA 3-6+ (IUCN)*", "national PA*",
                        "logging concession*","ITP concession*",
                        "IOPP concession*") )

lookup_names$name <- factor(lookup_names$name, levels = c("intercept","topography", "distance to roads",
                                                            "distance to rivers","density of fire", 
                                                          "population density",
                                                            "previous tree cover loss", 
                                                            "PA 1-3 (IUCN)*", "PA 3-6+ (IUCN)*", "national PA*",
                                                            "logging concession*","ITP concession*",
                                                            "IOPP concession*") )


parameters_m <- parameters %>%
  dplyr::select(-Iteration) %>%
  melt()%>%
  left_join(lookup_names, by ="variable") 

pdf("Parameter_histograms_ggplot.pdf", width =0, height = 0, paper = "a4r")
ggplot(data= parameters_m, aes(value))+
  geom_histogram(bins = 40)+
  facet_wrap(~name, scales = "free")+
  geom_vline(xintercept= 0, color = "red", size = 1, linetype = "dashed")+
  theme_bw() +
  xlab("parameter value") +
  ylab("frequency") +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 12, face = "bold", hjust = 1),
    axis.title=element_text(size = 12, face = "bold"),
    axis.text.x=element_text(angle=45),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=12),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 12, face="bold")) +
  theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
dev.off()


# the measure would be the distance of the median to zero and then plot this with a 
# a grey scale

parameters_s <- parameters_m %>%
  group_by(variable) %>%
  summarize(median = median(value))%>%
  mutate(delta = abs(median))



pdf("Parameter_histograms_ggplot_color_scale.pdf", width =0, height = 0, paper = "a4r")

ggplot(parameters_s, aes(y= delta, x= variable, color = delta))+
  geom_point(size=10)+
  # fix this
  scale_colour_gradient(low = "gray97", high = "gray8")+
  theme_bw()
dev.off()





parameters_m_s <- parameters_m %>%
  group_by(variable) %>%
  summarize(value = median(value),
            value_lower_ci = quantile(value, probs = 0.025),
            value_upper_ci = quantile(value, probs = 0.975),
            name = unique(name))%>%
  as.data.frame()

param_levels <- parameters_m_s$name[c(order(parameters_m_s[1:6, "value"]), order(parameters_m_s[7:length(unique(parameters_m$variable)), "value"])+6)]
parameters_m_s$name <- factor(parameters_m_s$name, levels = rev(param_levels))

pdf("Parameter_effect_size.pdf", width =0, height = 0, paper = "a4r")
ggplot(data = parameters_m_s, aes(x = value, y = name)) +
  geom_vline(xintercept= 0, color = "red", size = 1, linetype = "dashed")+
  #geom_jitter(height = 0.1, width = 0)+
  geom_point(shape = 18, fill = "black", size=4)+
 # geom_errorbarh(aes(xmin =parameters_m_s$value_lower_ci, xmax = parameters_m_s$value_upper_ci, height = 0.2))+
  theme_bw() +
  xlab("parameter value") +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 12, face = "bold", hjust = 1),
    axis.title=element_text(size = 12, face = "bold"),
    axis.text.x=element_text(angle=45),
    legend.text=element_text(size=12),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 12, face="bold")) +
  theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
dev.off()

