rm(list=ls())
library(tidyverse)
library(maptools)
library(raster)
library(reshape)
library(rgdal)
library(ggmap)
library(plotly)
options("scipen" = 100, "digits" = 4)
values.to.tif <- function(data_table,  # only id, x, y and value
                          crs_string,
                          outdir,
                          layer_name = "value_shape",
                          x = "x_start",
                          y = "y_start",
                          delete = T){
  
  
  # I need to know the name of the layer and also it needs to be fixed to
  # get it out of shapefile
  value_per_cell_sp <- as.data.frame(data_table)
  
  value_per_cell_sp <- SpatialPointsDataFrame(coords =
                                                cbind(value_per_cell_sp[ , x],
                                                      value_per_cell_sp[ , y]),
                                              data = value_per_cell_sp,
                                              proj4string = CRS(crs_string ),
                                              match.ID = T)
  shape_name <- paste0(layer_name, "_shapefile")
  print(paste("write shapefile", layer_name))
  writeOGR(value_per_cell_sp, dsn = outdir,
           layer = shape_name, driver = "ESRI Shapefile",
           overwrite = T)
  
  # pay attention that the tif gets a new name because later we delete all
  # with the same name as the shapefile
  system_string_ogrinfo <- paste0("ogrinfo -so -al ", outdir, "/", shape_name,  ".shp" )
  ogr_output  <- system(system_string_ogrinfo, intern = T)
  ogr_output <- ogr_output[length(ogr_output)]
  value_name_shp <- unlist(strsplit(ogr_output, ":"))[1]
  print(paste("rasterize", layer_name))
  system_string_rasterize <- paste0("gdal_rasterize -ot 'Float32' -a ", value_name_shp,
                                    " -tr 1000.0 1000.0 -l ", shape_name ,
                                    " ", outdir, "/", shape_name,  ".shp",
                                    " ", outdir, "/",
                                    layer_name, ".tif")
  system(system_string_rasterize)
  #delete the shapefile again because clogs up my system
  if(delete){ system_string_del <- paste0("rm -f ", outdir, "/", shape_name, ".*")
  system(system_string_del)}
}



inpath <- "~/Filzbach Examples/workspace"

crs_aea <- "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"

defor_prob <- readAsciiGrid(file.path(inpath, "sumprob2027_2031.asc"), proj4string = CRS(crs_aea)) %>%
  as.data.frame(defor_prob, xy= T) 


ou_dens <-  as.data.frame(raster("ou_pop_clip_repro_res.tif"), xy = T)

ou_dens$id <- paste0(round(ou_dens$x), "_", round(ou_dens$y))
defor_prob$id <- paste0(defor_prob$s1, "_", defor_prob$s2)


defor_ou <- defor_prob %>% 
  inner_join(ou_dens, by = c("id")) %>%
  dplyr::select(
    x,
    y,
    id,
    defor_prob =sumprob2027_2031.asc,
    ou_dens =  ou_pop_clip_repro_res
  )



# could we do cluster analysis

# now we also make the stuff for the bivariate chloropleth map
# see(http://www.joshuastevens.net/cartography/make-a-bivariate-choropleth-map/)
# also check here: https://cran.r-project.org/web/packages/pals/vignettes/bivariate_choropleths.html
defor_ou$defor_class <- NA
defor_ou$ou_class <- NA

defor_ou[defor_ou$defor_prob < 100/3, "defor_class"] <- "A"
defor_ou[defor_ou$defor_prob >= 100/3 & defor_ou$defor_prob < (100/3*2), "defor_class"] <- "B"
defor_ou[defor_ou$defor_prob >= 100/3*2, "defor_class"] <- "C"

defor_ou[defor_ou$ou_dens < 0.01, "ou_class"] <- "0"
defor_ou[defor_ou$ou_dens >= 0.01 & defor_ou$ou_dens < 0.5, "ou_class"] <- "1"
defor_ou[defor_ou$ou_dens >= 0.5 & defor_ou$ou_dens < 2, "ou_class"] <- "2"
defor_ou[defor_ou$ou_dens >= 2, "ou_class"] <- "3"


defor_ou$bi_class_temp <- as.factor(paste0(defor_ou$defor_class, defor_ou$ou_class ))

# reclassify them as numbers so that we can make a raster
defor_ou[defor_ou$bi_class_temp == "A0", "bi_class"] <- 0
defor_ou[defor_ou$bi_class_temp == "B0", "bi_class"] <- 0
defor_ou[defor_ou$bi_class_temp == "C0", "bi_class"] <- 0



defor_ou[defor_ou$bi_class_temp == "A1", "bi_class"] <- 1
defor_ou[defor_ou$bi_class_temp == "B1", "bi_class"] <- 2
defor_ou[defor_ou$bi_class_temp == "C1", "bi_class"] <- 3

defor_ou[defor_ou$bi_class_temp == "A2", "bi_class"] <- 4
defor_ou[defor_ou$bi_class_temp == "B2", "bi_class"] <- 5
defor_ou[defor_ou$bi_class_temp == "C2", "bi_class"] <- 6

defor_ou[defor_ou$bi_class_temp == "A3", "bi_class"] <- 7
defor_ou[defor_ou$bi_class_temp == "B3", "bi_class"] <- 8
defor_ou[defor_ou$bi_class_temp == "C3", "bi_class"] <- 9

defor_ou$bi_class <- as.factor(defor_ou$bi_class)
summary(defor_ou)

defor_ou_raster <- dplyr::select(defor_ou, id, x, y, bi_class)

values.to.tif(defor_ou_raster,  # only id, x, y and value
                          crs_aea,
                          "H:/",
                          layer_name = "defor_ou_chloropleth_road_ou_clip",
                          x = "x",
                          y = "y")

raster("H:/defor_ou_chloropleth_road_ou_clip.tif")



# for legend
legend_numbers <- defor_ou %>%
  group_by(bi_class) %>%
  summarize(count = n(),
            perc = round((n()*100/nrow(defor_ou)),1))