#script to clculate percentage and numbers of LU

rm(list=ls())
library(tidyverse)
library(foreach)
library(reshape2)

ou_baseline <- read.csv("~/Filzbach Examples/workspace/ou_baseline.csv")



ou_lu <- ou_baseline %>%
  filter(category == "lu" & type == "ou" & year == 0 & province =="Borneo" & i == 0) %>%
  dplyr::rename(lu = class)
sum_ou <- sum(ou_lu$nr_ou)

lu_types = sort(unique(ou_lu$lu))

ou_lu <- ou_lu %>%
  mutate(perc_ou = nr_ou * 100 / sum_ou)

lookup_lu_types <- data.frame(lu = lu_types, lu_name = c("no PA, no concession", "IUCN 1-3", "IUCN 3-6,others", 
                                                         "other national PAs", "logging concession", "ITP","oil palm concession"),
                              lu_short = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))
lookup_lu_types$lu_name <- factor(lookup_lu_types$lu_name, levels = c( "IUCN 1-3", "IUCN 3-6,others", 
                                                                       "other national PAs",
                                                                       "logging concession", "ITP", "oil palm concession",  "no PA, no concession"))

ou_lu <- left_join(ou_lu, lookup_lu_types, by = "lu")


pdf("~/Filzbach Examples/workspace/ou_per_lu_barchart.pdf", width = 0, height = 0, paper = "a4r")

ggplot(data = ou_lu, aes(y = perc_ou, x = "", fill = as.factor(lu_name)))+
  geom_bar(stat = "identity")+
   xlab("% orangutans per category") +
  theme_bw()+
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    axis.title=element_text(size = 18, face = "bold"),
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,0.2,0.1,0.1),"cm"))
dev.off()

# ou perc in pa and logging
sum(ou_lu[ou_lu$lu_short %in% c("PA1", "PA2", "PA3", "LC"), "perc_ou"])
# ou perc in plantation and no designation
sum(ou_lu[ou_lu$lu_short %in% c("ITP", "OPC", "other"), "perc_ou"])


# in case I want to lump PAs----
# ou_lu$lu_name <- as.character(ou_lu$lu_name)
# ou_lu[ou_lu$lu_name %in% c( "IUCN 1-3", "IUCN 3-6,others", 
#                             "other national PAs"), "lu_name"] <- "PAs"
# 
# ou_lu$lu_name <- as.factor(ou_lu$lu_name)
# lookup_lu_types$lu_name <- factor(lookup_lu_types$lu_name, levels = c( "PAs",
#                                                                        "logging concession", "ITP", "oil palm concession",  "no PA, no concession"))
# 
# 
# ggplot(data = ou_lu, aes(y = nr_ou, x = "", fill = as.factor(lu_name)))+
#   geom_bar(stat = "identity")
# 

# calculating the numbers of decline ----
ou_loss_lu_2031 <- ou_baseline %>%
  filter(category == "lu" & type == "ou_loss" & year == 3 & province =="Borneo") %>%
  rename(lu = class) %>%
  left_join(lookup_lu_types, by = "lu")%>%
  mutate(lu_lumped = as.character(lu_name))

ou_loss_lu_2031[ou_loss_lu_2031$lu_lumped %in%  c( "IUCN 1-3", "IUCN 3-6,others", 
                                                   "other national PAs"), "lu_lumped"] <- "PA"
ou_loss_lu_2031[ou_loss_lu_2031$lu_lumped %in%  c( "ITP", 
                                                   "oil palm concession"), "lu_lumped"] <- "IP"


# we have to sum always the number of ou within PA, not just give it the same name
ou_loss_lu_2031_full <- ou_loss_lu_2031 %>%  
  group_by(lu_name)%>%
  summarize(
    median_ou_loss = round(median(nr_ou), -2),
    lower_ci_ou_loss =  round(quantile(nr_ou, probs = 0.025), -2),
    upper_ci_ou_loss = round(quantile(nr_ou, probs = 0.975), -2)
  )



# lumped numbers of decline
ou_loss_lu_2031_lumped <-ou_loss_lu_2031 %>%  
  group_by(lu_lumped, i)%>%
  summarize(nr_ou_sum = sum(nr_ou))%>%
  group_by(lu_lumped)%>%
  summarize(
    median_ou_loss = round(median(nr_ou_sum),-2),
    lower_ci_ou_loss =  round(quantile(nr_ou_sum, probs = 0.025), -2),
    upper_ci_ou_loss = round(quantile(nr_ou_sum, probs = 0.975), -2)
  )

# in total how much ou loss
round(sum(ou_loss_lu_2031_lumped$median_ou_loss), -2)

# in not designated
ou_loss_lu_2031_lumped[ou_loss_lu_2031_lumped$lu_lumped == "no PA, no concession", "median_ou_loss"] *100/sum(ou_loss_lu_2031_lumped[, "median_ou_loss"])



write.csv(ou_loss_lu_2031_full, "~/Filzbach Examples/workspace/ou_loss_lu_2031_full.csv", row.names = F)

write.csv(ou_loss_lu_2031_lumped, "~/Filzbach Examples/workspace/ou_loss_lu_2031_lumped.csv", row.names = F)


# per province and lu



ou_lu <- ou_baseline %>%
  filter(category == "lu" & type == "ou" & year == 0 & province !="Borneo" & i == 0) %>%
  rename(lu = class)
sum_ou <- sum(ou_lu$nr_ou)


lu_types = sort(unique(ou_lu$lu))

ou_lu <- ou_lu %>%
  mutate(perc_ou = nr_ou * 100 / sum_ou)

lookup_lu_types <- data.frame(lu = lu_types, lu_name = c("no PA, no concession", "IUCN 1-3", "IUCN 3-6,others", 
                                                         "other national PAs", "logging concession", "ITP","oil palm concession"),
                              lu_short = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))
lookup_lu_types$lu_name <- factor(lookup_lu_types$lu_name, levels = c( "IUCN 1-3", "IUCN 3-6,others", 
                                                                       "other national PAs",
                                                                       "logging concession", "ITP", "oil palm concession",  "no PA, no concession"))

ou_lu <- left_join(ou_lu, lookup_lu_types, by = "lu")

provinces = sort(unique(ou_lu$province))

lookup_provinces <- data.frame(province = provinces, province_name = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                       "Central Kal", "East Kal","North Kal" ),
                               province_short = c("Sab", "Saw", "WK", "SK", "CK", "EK", "NK"))


lookup_provinces$province_name <- factor(lookup_provinces$province_name, levels = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                                    "Central Kal", "East Kal","North Kal" ))
lookup_provinces$province_short <- factor(lookup_provinces$province_short, levels = c("Sab", "Saw", "WK", "SK", "CK", "EK", "NK"))

ou_lu <- ou_lu %>%
  left_join(lookup_provinces, by = "province")



# calculating the numbers of decline ----
ou_loss_lu_2031 <- ou_baseline %>%
  filter(category == "lu" & type == "ou_loss" & year == 3 & province !="Borneo") %>%
  rename(lu = class) %>%
  left_join(lookup_lu_types, by = "lu")%>%
  mutate(lu_lumped = as.character(lu_name)) %>%
  left_join(lookup_provinces, by = "province")

ou_loss_lu_2031[ou_loss_lu_2031$lu_lumped %in%  c( "IUCN 1-3", "IUCN 3-6,others", 
                                                   "other national PAs"), "lu_lumped"] <- "PA"
ou_loss_lu_2031[ou_loss_lu_2031$lu_lumped %in%  c( "ITP", 
                                                   "oil palm concession"), "lu_lumped"] <- "IP"


# we have to sum always the number of ou within PA, not just give it the same name
ou_loss_lu_2031_full <- ou_loss_lu_2031 %>%  
  group_by(lu_name, province_name)%>%
  summarize(
    median_ou_loss = round(median(nr_ou), -2),
    lower_ci_ou_loss =  round(quantile(nr_ou, probs = 0.025), -2),
    upper_ci_ou_loss = round(quantile(nr_ou, probs = 0.975), -2)
  )



# lumped numbers of decline
ou_loss_lu_2031_lumped <-ou_loss_lu_2031 %>%  
  group_by(lu_lumped, province_name, i)%>%
  summarize(nr_ou_sum = sum(nr_ou))%>%
  group_by(lu_lumped, province_name)%>%
  summarize(
    median_ou_loss = median(nr_ou_sum),
    lower_ci_ou_loss =  quantile(nr_ou_sum, probs = 0.025),
    upper_ci_ou_loss = quantile(nr_ou_sum, probs = 0.975)
  )


Sabah <- filter(ou_loss_lu_2031_lumped, province_name == "Sabah")

write.csv(ou_loss_lu_2031_full, "~/Filzbach Examples/workspace/ou_loss_lu_2031_full.csv", row.names = F)

write.csv(ou_loss_lu_2031_lumped, "~/Filzbach Examples/workspace/ou_loss_lu_2031_lumped.csv", row.names = F)
