# script to produce both observed and predicted deforestation in Borneo

rm(list=ls())
library(tidyverse)
library(foreach)
library(reshape2)

options("scipen" = 100, "digits" = 10)
values.to.tif <- function(data_table,  # only id, x, y and value
                          crs_string,
                          outdir,
                          layer_name = "value_shape",
                          x = "x_start",
                          y = "y_start",
                          delete = T){
  
  
  # I need to know the name of the layer and also it needs to be fixed to
  # get it out of shapefile
  value_per_cell_sp <- as.data.frame(data_table)
  
  value_per_cell_sp <- SpatialPointsDataFrame(coords =
                                                cbind(value_per_cell_sp[ , x],
                                                      value_per_cell_sp[ , y]),
                                              data = value_per_cell_sp,
                                              proj4string = CRS(crs_string ),
                                              match.ID = T)
  shape_name <- paste0(layer_name, "_shapefile")
  print(paste("write shapefile", layer_name))
  writeOGR(value_per_cell_sp, dsn = outdir,
           layer = shape_name, driver = "ESRI Shapefile",
           overwrite = T)
  
  # pay attention that the tif gets a new name because later we delete all
  # with the same name as the shapefile
  system_string_ogrinfo <- paste0("ogrinfo -so -al ", outdir, "/", shape_name,  ".shp" )
  ogr_output  <- system(system_string_ogrinfo, intern = T)
  ogr_output <- ogr_output[length(ogr_output)]
  value_name_shp <- unlist(strsplit(ogr_output, ":"))[1]
  print(paste("rasterize", layer_name))
  system_string_rasterize <- paste0("gdal_rasterize -ot 'Float32' -a ", value_name_shp,
                                    " -tr 1000.0 1000.0 -l ", shape_name ,
                                    " ", outdir, "/", shape_name,  ".shp",
                                    " ", outdir, "/",
                                    layer_name, ".tif")
  system(system_string_rasterize)
  #delete the shapefile again because clogs up my system
  if(delete){ system_string_del <- paste0("rm -f ", outdir, "/", shape_name, ".*")
  system(system_string_del)}
}


# recode the map ----

inpath <- "~/Filzbach Examples/workspace"
crs_aea <- "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"

defor_prob <- readAsciiGrid(file.path(inpath, "sumprob2027_2031.asc"), proj4string = CRS(crs_aea)) %>%
  as.data.frame(defor_prob, xy= T) 


ou_dens <-  as.data.frame(raster("~/Filzbach Examples/workspace/ou_pop_clip_repro_res.tif"), xy = T)

ou_dens$id <- paste0(round(ou_dens$x), "_", round(ou_dens$y))
defor_prob$id <- paste0(defor_prob$s1, "_", defor_prob$s2)


defor_ou <- defor_prob %>% 
  inner_join(ou_dens, by = c("id")) %>%
  dplyr::select(
    x,
    y,
    id,
    defor_prob =sumprob2027_2031.asc,
    ou_dens =  ou_pop_clip_repro_res
  )



# could we do cluster analysis

# now we also make the stuff for the bivariate chloropleth map
# see(http://www.joshuastevens.net/cartography/make-a-bivariate-choropleth-map/)
# also check here: https://cran.r-project.org/web/packages/pals/vignettes/bivariate_choropleths.html
defor_ou$defor_class <- NA
defor_ou$ou_class <- NA

defor_ou[defor_ou$defor_prob < 100/3, "defor_class"] <- "A"
defor_ou[defor_ou$defor_prob >= 100/3 & defor_ou$defor_prob < (100/3*2), "defor_class"] <- "B"
defor_ou[defor_ou$defor_prob >= 100/3*2, "defor_class"] <- "C"

defor_ou[defor_ou$ou_dens < 0.01, "ou_class"] <- "0"
defor_ou[defor_ou$ou_dens >= 0.01 & defor_ou$ou_dens < 0.5, "ou_class"] <- "1"
defor_ou[defor_ou$ou_dens >= 0.5 & defor_ou$ou_dens < 2, "ou_class"] <- "2"
defor_ou[defor_ou$ou_dens >= 2, "ou_class"] <- "3"


defor_ou$bi_class_temp <- as.factor(paste0(defor_ou$defor_class, defor_ou$ou_class ))

# reclassify them as numbers so that we can make a raster
defor_ou[defor_ou$bi_class_temp == "A0", "bi_class"] <- 0
defor_ou[defor_ou$bi_class_temp == "B0", "bi_class"] <- 0
defor_ou[defor_ou$bi_class_temp == "C0", "bi_class"] <- 0

defor_ou[defor_ou$bi_class_temp == "A1", "bi_class"] <- 1
defor_ou[defor_ou$bi_class_temp == "B1", "bi_class"] <- 2
defor_ou[defor_ou$bi_class_temp == "C1", "bi_class"] <- 3

defor_ou[defor_ou$bi_class_temp == "A2", "bi_class"] <- 4
defor_ou[defor_ou$bi_class_temp == "B2", "bi_class"] <- 5
defor_ou[defor_ou$bi_class_temp == "C2", "bi_class"] <- 6

defor_ou[defor_ou$bi_class_temp == "A3", "bi_class"] <- 7
defor_ou[defor_ou$bi_class_temp == "B3", "bi_class"] <- 8
defor_ou[defor_ou$bi_class_temp == "C3", "bi_class"] <- 9

defor_ou$bi_class <- as.factor(defor_ou$bi_class)
summary(defor_ou)

color_scheme <- c("#dddddd","#dd7c8a","#cc0024",  "#7bb3d1", "#8d6c8f", "#8a274a","#016eae", 
                  "#4a4779",   "#4b264d")





# splitting this up, would be super beautiful!
# join this with landuse layer and with the province layer

lu <-  as.data.frame(raster("~/Filzbach Examples/workspace/LU_PA_0_1_repro_res.tif"), xy = T)
province <- as.data.frame(raster("~/Filzbach Examples/workspace/province_repro_res.tif"), xy = T)


defor_ou <- defor_ou %>%
  left_join(lu, by = c("x", "y")) %>%
  left_join(province, by = c("x", "y")) %>%
  dplyr::rename(lu =  LU_PA_0_1_repro_res,
                province = province_repro_res) %>%
  filter(province != 8) # EXCLUDE BRUNEI HERE


lu_types = sort(unique(defor_ou$lu))

lookup_lu_types <- data.frame(lu = lu_types, lu_name = c("no PA, no concession", "IUCN 1-3", "IUCN 3-6,others", 
                                                         "other national PAs", "logging concession", "ITP","oil palm concession"),
                              lu_short = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))
lookup_lu_types$lu_name <- factor(lookup_lu_types$lu_name, levels = c( "IUCN 1-3", "IUCN 3-6,others", 
                                                                       "other national PAs", "no PA, no concession",
                                                                       "logging concession", "ITP", "oil palm concession"))
lookup_lu_types$lu_short <- factor(lookup_lu_types$lu_short, levels = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))

defor_ou <- left_join(defor_ou, lookup_lu_types, by = "lu")


# 1PA ----
# reclassify them as numbers so that we can make a raster

# for the different scenarios we recode the map
# try to get map only with this LU
defor_ou_pa <- defor_ou
defor_ou_pa$bi_class <- as.integer(as.character(defor_ou_pa$bi_class))
defor_ou_pa[!defor_ou_pa$lu_name %in% c( "IUCN 1-3", "IUCN 3-6,others", 
                         "other national PAs"), "bi_class" ] <- 0

defor_ou_pa_raster <- dplyr::select(defor_ou_pa, id, x, y, bi_class)

values.to.tif(defor_ou_pa_raster,  # only id, x, y and value
                          crs_aea,
                          "H:/",
                          layer_name = "defor_ou_chloropleth_PA_ou_clip",
                          x = "x",
                          y = "y",
              delete = F)




# 2 Logging concessions----


defor_ou_logging <- defor_ou
defor_ou_logging$bi_class <- as.integer(as.character(defor_ou_logging$bi_class))
defor_ou_logging[!defor_ou_logging$lu_name %in% c("logging concession" ), "bi_class" ] <- 0

defor_ou_logging_raster <- dplyr::select(defor_ou_logging, id, x, y, bi_class)

values.to.tif(defor_ou_logging_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_ou_chloropleth_logging_ou_clip",
              x = "x",
              y = "y",
              delete = F)





# 3 ITP concessions----


defor_ou_ITP <- defor_ou
defor_ou_ITP$bi_class <- as.integer(as.character(defor_ou_ITP$bi_class))
defor_ou_ITP[!defor_ou_ITP$lu_name %in% c("ITP" ), "bi_class" ] <- 0

defor_ou_ITP_raster <- dplyr::select(defor_ou_ITP, id, x, y, bi_class)

values.to.tif(defor_ou_ITP_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_ou_chloropleth_ITP_ou_clip",
              x = "x",
              y = "y",
              delete = F)





# 4 IOPP concessions----


defor_ou_IOPP <- defor_ou
defor_ou_IOPP$bi_class <- as.integer(as.character(defor_ou_IOPP$bi_class))
defor_ou_IOPP[!defor_ou_IOPP$lu_name %in% c("oil palm concession" ), "bi_class" ] <- 0

defor_ou_IOPP_raster <- dplyr::select(defor_ou_IOPP, id, x, y, bi_class)

values.to.tif(defor_ou_IOPP_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_ou_chloropleth_IOPP_ou_clip",
              x = "x",
              y = "y",
              delete = F)




#3-4 combined concessions----


defor_ou_IP <- defor_ou
defor_ou_IP$bi_class <- as.integer(as.character(defor_ou_IP$bi_class))
defor_ou_IP[!defor_ou_IP$lu_name %in% c("ITP", "oil palm concession" ), "bi_class" ] <- 0

defor_ou_IP_raster <- dplyr::select(defor_ou_IP, id, x, y, bi_class)

values.to.tif(defor_ou_IP_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_ou_chloropleth_IP_ou_clip",
              x = "x",
              y = "y",
              delete = F)




# 5 nothing concessions----


defor_ou_nothing <- defor_ou
defor_ou_nothing$bi_class <- as.integer(as.character(defor_ou_nothing$bi_class))
defor_ou_nothing[!defor_ou_nothing$lu_name %in% c("no PA, no concession" ), "bi_class" ] <- 0

defor_ou_nothing_raster <- dplyr::select(defor_ou_nothing, id, x, y, bi_class)

values.to.tif(defor_ou_nothing_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_ou_chloropleth_nothing_ou_clip",
              x = "x",
              y = "y",
              delete = F)


