rm(list=ls())
library(tidyverse)
library(maptools)
library(raster)
library(reshape)
library(rgdal)
library(ggmap)
library(plotly)
options("scipen" = 100, "digits" = 4)
values.to.tif <- function(data_table,  # only id, x, y and value
                          crs_string,
                          outdir,
                          layer_name = "value_shape",
                          x = "x_start",
                          y = "y_start",
                          delete = T){
  
  
  # I need to know the name of the layer and also it needs to be fixed to
  # get it out of shapefile
  value_per_cell_sp <- as.data.frame(data_table)
  
  value_per_cell_sp <- SpatialPointsDataFrame(coords =
                                                cbind(value_per_cell_sp[ , x],
                                                      value_per_cell_sp[ , y]),
                                              data = value_per_cell_sp,
                                              proj4string = CRS(crs_string ),
                                              match.ID = T)
  shape_name <- paste0(layer_name, "_shapefile")
  print(paste("write shapefile", layer_name))
  writeOGR(value_per_cell_sp, dsn = outdir,
           layer = shape_name, driver = "ESRI Shapefile",
           overwrite = T)
  
  # pay attention that the tif gets a new name because later we delete all
  # with the same name as the shapefile
  system_string_ogrinfo <- paste0("ogrinfo -so -al ", outdir, "/", shape_name,  ".shp" )
  ogr_output  <- system(system_string_ogrinfo, intern = T)
  ogr_output <- ogr_output[length(ogr_output)]
  value_name_shp <- unlist(strsplit(ogr_output, ":"))[1]
  print(paste("rasterize", layer_name))
  system_string_rasterize <- paste0("gdal_rasterize -ot 'Float32' -a ", value_name_shp,
                                    " -tr 1000.0 1000.0 -l ", shape_name ,
                                    " ", outdir, "/", shape_name,  ".shp",
                                    " ", outdir, "/",
                                    layer_name, ".tif")
  system(system_string_rasterize)
  #delete the shapefile again because clogs up my system
  if(delete){ system_string_del <- paste0("rm -f ", outdir, "/", shape_name, ".*")
  system(system_string_del)}
}



inpath <- "~/Filzbach Examples/workspace"
crs_aea <- "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"

defor_prob <- readAsciiGrid(file.path(inpath, "sumprob2027_2031.asc"), proj4string = CRS(crs_aea)) %>%
  as.data.frame(defor_prob, xy= T) 


ou_dens <-  as.data.frame(raster("~/Filzbach Examples/workspace/ou_pop_clip_repro_res.tif"), xy = T)

ou_dens$id <- paste0(round(ou_dens$x), "_", round(ou_dens$y))
defor_prob$id <- paste0(defor_prob$s1, "_", defor_prob$s2)


defor_ou <- defor_prob %>% 
  inner_join(ou_dens, by = c("id")) %>%
  dplyr::select(
    x,
    y,
    id,
    defor_prob =sumprob2027_2031.asc,
    ou_dens =  ou_pop_clip_repro_res
  )



# could we do cluster analysis

# now we also make the stuff for the bivariate chloropleth map
# see(http://www.joshuastevens.net/cartography/make-a-bivariate-choropleth-map/)
# also check here: https://cran.r-project.org/web/packages/pals/vignettes/bivariate_choropleths.html
defor_ou$defor_class <- NA
defor_ou$ou_class <- NA

defor_ou[defor_ou$defor_prob < 100/3, "defor_class"] <- "A"
defor_ou[defor_ou$defor_prob >= 100/3 & defor_ou$defor_prob < (100/3*2), "defor_class"] <- "B"
defor_ou[defor_ou$defor_prob >= 100/3*2, "defor_class"] <- "C"

defor_ou[defor_ou$ou_dens < 0.01, "ou_class"] <- "0"
defor_ou[defor_ou$ou_dens >= 0.01 & defor_ou$ou_dens < 0.5, "ou_class"] <- "1"
defor_ou[defor_ou$ou_dens >= 0.5 & defor_ou$ou_dens < 2, "ou_class"] <- "2"
defor_ou[defor_ou$ou_dens >= 2, "ou_class"] <- "3"


defor_ou$bi_class_temp <- as.factor(paste0(defor_ou$defor_class, defor_ou$ou_class ))

# reclassify them as numbers so that we can make a raster
defor_ou[defor_ou$bi_class_temp == "A1", "bi_class"] <- 1
defor_ou[defor_ou$bi_class_temp == "B1", "bi_class"] <- 2
defor_ou[defor_ou$bi_class_temp == "C1", "bi_class"] <- 3

defor_ou[defor_ou$bi_class_temp == "A2", "bi_class"] <- 4
defor_ou[defor_ou$bi_class_temp == "B2", "bi_class"] <- 5
defor_ou[defor_ou$bi_class_temp == "C2", "bi_class"] <- 6

defor_ou[defor_ou$bi_class_temp == "A3", "bi_class"] <- 7
defor_ou[defor_ou$bi_class_temp == "B3", "bi_class"] <- 8
defor_ou[defor_ou$bi_class_temp == "C3", "bi_class"] <- 9

defor_ou$bi_class <- as.factor(defor_ou$bi_class)
summary(defor_ou)
defor_ou_raster <- dplyr::select(defor_ou, id, x, y, bi_class)

values.to.tif(defor_ou_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_ou_chloropleth_road",
              x = "x",
              y = "y")


# only deforestation

defor_raster <- dplyr::select(defor_ou, id, x, y, defor_class)%>%
  mutate(defor_class = as.numeric(as.factor(defor_class)))

values.to.tif(defor_raster,  # only id, x, y and value
              crs_aea,
              "H:/",
              layer_name = "defor_chloropleth_road",
              x = "x",
              y = "y")



# only OU (no forest cutting)

ou_dens <-  as.data.frame(raster("~/Filzbach Examples/workspace/ou_pop_clip_no_forest_repro_res.tif"), xy = T)
names(ou_dens)<- c("x", "y", "ou_dens")

ou_dens[ou_dens$ou_dens < 0.01, "ou_class"] <- 0
ou_dens[ou_dens$ou_dens >= 0.01 & ou_dens$ou_dens < 0.5, "ou_class"] <- 1
ou_dens[ou_dens$ou_dens >= 0.5 & ou_dens$ou_dens < 2, "ou_class"] <-4
ou_dens[ou_dens$ou_dens >= 2, "ou_class"] <- 7
ou_dens$id <- 1:nrow(ou_dens)

defor_raster <- dplyr::select(ou_dens, id, x, y, ou_class)

values.to.tif(defor_raster,  # only id, x, y and ou_class
              crs_aea,
              "H:/",
              layer_name = "defor_chloropleth_ou",
              x = "x",
              y = "y")


# for legend
legend_numbers <- defor_ou %>%
  group_by(bi_class) %>%
  summarize(count = n(),
            perc = round((n()*100/nrow(defor_ou)),1))



color_scheme <- c("#dddddd","#dd7c8a","#cc0024",  "#7bb3d1", "#8d6c8f", "#8a274a","#016eae", 
                  "#4a4779",   "#4b264d")


# splitting up in provinces and lu

lu <-  as.data.frame(raster("~/Filzbach Examples/workspace/LU_PA_0_1_repro_res.tif"), xy = T)
province <- as.data.frame(raster("~/Filzbach Examples/workspace/province_repro_res.tif"), xy = T)


defor_ou <- defor_ou %>%
  left_join(lu, by = c("x", "y")) %>%
  left_join(province, by = c("x", "y")) %>%
  dplyr::rename(lu =  LU_PA_0_1_repro_res,
                province = province_repro_res) %>%
  filter(province != 8) # EXCLUDE BRUNEI HERE


lu_types = sort(unique(defor_ou$lu))

lookup_lu_types <- data.frame(lu = lu_types, lu_name = c("no PA, no concession", "IUCN 1-3", "IUCN 3-6,others", 
                                                         "other national PAs", "logging concession", "ITP","oil palm concession"),
                              lu_short = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))
lookup_lu_types$lu_name <- factor(lookup_lu_types$lu_name, levels = c( "IUCN 1-3", "IUCN 3-6,others", 
                                                                       "other national PAs", "no PA, no concession",
                                                                       "logging concession", "ITP", "oil palm concession"))
lookup_lu_types$lu_short <- factor(lookup_lu_types$lu_short, levels = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))

defor_ou <- left_join(defor_ou, lookup_lu_types, by = "lu")



pdf("~/Filzbach Examples/workspace/ou_dens_deforest_lu_class_road.pdf", width = 0, height = 0, paper = "a4r")
ggplot(defor_ou, aes(y= ou_dens, x = defor_prob, color = bi_class)) +
  geom_point(alpha = 0.3)+
  scale_color_manual(values = color_scheme)+
  theme_bw()+
  facet_wrap(~lu_name)+
  xlab("summed deforestation probability") +
  ylab(as.expression(bquote("orangutan number per" ~ km^2 ~ ""))) +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    axis.ticks.y = element_blank(),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
dev.off()



provinces = sort(unique(defor_ou$province))

lookup_provinces <- data.frame(province = provinces, province_name = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                       "Central Kal", "East Kal","North Kal" ),
                               province_short = c("Sab", "Saw", "WK", "SK", "CK", "EK", "NK"))


lookup_provinces$province_name <- factor(lookup_provinces$province_name, levels = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                                    "Central Kal", "East Kal","North Kal" ))
lookup_provinces$province_short <- factor(lookup_provinces$province_short, levels = c("Sab", "Saw", "WK", "SK", "CK", "EK", "NK"))

defor_ou <- defor_ou %>%
  left_join(lookup_provinces, by = "province")

defor_ou$country <- NA
defor_ou[defor_ou$province_name %in% c("Sarawak", "Sabah"), "country"] <- "Malaysia"
defor_ou[!(defor_ou$province_name %in% c("Sarawak", "Sabah")), "country"] <- "Indonesia"


defor_ou <- filter(defor_ou, !province_name %in% c("North Kal", "South Kal"))

pdf("~/Filzbach Examples/workspace/ou_dens_deforest_province_class.pdf", width = 0, height = 0, paper = "a4r")

ggplot(defor_ou, aes(y= ou_dens, x = defor_prob, color = bi_class)) +
  geom_point(alpha = 0.3)+
  scale_color_manual(values = color_scheme)+
  scale_x_continuous(breaks = c(33,67, 100), labels =c(33, 67, 100))+
  scale_y_continuous(breaks = c(0.5, 2, 4 ), labels = c(0.5, 2, 4), limits = c(0, max(defor_ou$ou_dens)+0.2))+
  facet_wrap(~province_name, scales = "free")+
  theme_bw()+
  xlab("summed deforestation probability") +
  ylab(as.expression(bquote("orangutan number per" ~ km^2 ~ ""))) +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    axis.ticks.y = element_blank(),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
dev.off()



# create an empty file to work with in inkscape
defor_ou_test <- rbind(defor_ou[defor_ou$province_short == "Sab", ][1, ], 
                       defor_ou[defor_ou$province_short == "Saw", ][1, ],
                       defor_ou[defor_ou$province_short == "CK", ][1, ],
                       defor_ou[defor_ou$province_short == "WK", ][1, ],
                       defor_ou[defor_ou$province_short == "EK", ][1, ])


pdf("~/Filzbach Examples/workspace/ou_dens_deforest_province_class_empty.pdf", width = 0, height = 0, paper = "a4r")

ggplot(defor_ou_test, aes(y= ou_dens, x = defor_prob, color = bi_class)) +
  geom_point(alpha = 0.3)+
  scale_color_manual(values = color_scheme)+
  scale_x_continuous(breaks = c(33,67, 100), labels =c(33, 67, 100), limits = c(0, 100))+
  scale_y_continuous(breaks = c(0.5, 2, 4 ), labels = c(0.5, 2, 4), limits = c(0, max(defor_ou$ou_dens)+0.2))+
  facet_wrap(~province_name, scales = "free")+
  theme_bw()+
  xlab("summed deforestation probability") +
  ylab(as.expression(bquote("orangutan number per" ~ km^2 ~ ""))) +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
dev.off()
