rm(list=ls())
library(tidyverse)
library(maptools)
library(raster)
library(reshape)
library(rgdal)
library(ggmap)
library(plotly)
options("scipen" = 100, "digits" = 4)
inpath <- "~/Filzbach Examples/workspace"
crs_aea <- "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"

defor_prob <- readAsciiGrid(file.path(inpath, "sumprob2027_2031.asc"), proj4string = CRS(crs_aea)) %>%
  as.data.frame(defor_prob, xy= T) 


ou_dens <-  as.data.frame(raster("~/Filzbach Examples/workspace/ou_pop_clip_repro_res.tif"), xy = T)

ou_dens$id <- paste0(round(ou_dens$x), "_", round(ou_dens$y))
defor_prob$id <- paste0(defor_prob$s1, "_", defor_prob$s2)


defor_ou <- defor_prob %>% 
  inner_join(ou_dens, by = c("id")) %>%
  dplyr::select(
    x,
    y,
    id,
    defor_prob =sumprob2027_2031.asc,
    ou_dens =  ou_pop_clip_repro_res
  )



# could we do cluster analysis

# now we also make the stuff for the bivariate chloropleth map
# see(http://www.joshuastevens.net/cartography/make-a-bivariate-choropleth-map/)
# also check here: https://cran.r-project.org/web/packages/pals/vignettes/bivariate_choropleths.html
defor_ou$defor_class <- NA
defor_ou$ou_class <- NA

defor_ou[defor_ou$defor_prob < 100/3, "defor_class"] <- "A"
defor_ou[defor_ou$defor_prob >= 100/3 & defor_ou$defor_prob < (100/3*2), "defor_class"] <- "B"
defor_ou[defor_ou$defor_prob >= 100/3*2, "defor_class"] <- "C"

defor_ou[defor_ou$ou_dens < 0.01, "ou_class"] <- "0"
defor_ou[defor_ou$ou_dens >= 0.01 & defor_ou$ou_dens < 0.5, "ou_class"] <- "1"
defor_ou[defor_ou$ou_dens >= 0.5 & defor_ou$ou_dens < 2, "ou_class"] <- "2"
defor_ou[defor_ou$ou_dens >= 2, "ou_class"] <- "3"


defor_ou$bi_class_temp <- as.factor(paste0(defor_ou$defor_class, defor_ou$ou_class ))

# reclassify them as numbers so that we can make a raster----

# reclassify them as numbers so that we can make a raster
defor_ou[defor_ou$bi_class_temp == "A0", "bi_class"] <- 0
defor_ou[defor_ou$bi_class_temp == "B0", "bi_class"] <- 0
defor_ou[defor_ou$bi_class_temp == "C0", "bi_class"] <- 0

defor_ou[defor_ou$bi_class_temp == "A1", "bi_class"] <- 1
defor_ou[defor_ou$bi_class_temp == "B1", "bi_class"] <- 2
defor_ou[defor_ou$bi_class_temp == "C1", "bi_class"] <- 3

defor_ou[defor_ou$bi_class_temp == "A2", "bi_class"] <- 1
defor_ou[defor_ou$bi_class_temp == "B2", "bi_class"] <- 2
defor_ou[defor_ou$bi_class_temp == "C2", "bi_class"] <- 3

defor_ou[defor_ou$bi_class_temp == "A3", "bi_class"] <- 1
defor_ou[defor_ou$bi_class_temp == "B3", "bi_class"] <- 2
defor_ou[defor_ou$bi_class_temp == "C3", "bi_class"] <- 3

defor_ou$bi_class <- as.factor(defor_ou$bi_class)
summary(defor_ou)


color_scheme <- c("#dddddd","#dd7c8a","#cc0024")


# splitting this up, would be super beautiful!
# join this with landuse layer and with the province layer

lu <-  as.data.frame(raster("~/Filzbach Examples/workspace/LU_PA_0_1_repro_res.tif"), xy = T)
province <- as.data.frame(raster("~/Filzbach Examples/workspace/province_repro_res.tif"), xy = T)


defor_ou <- defor_ou %>%
  left_join(lu, by = c("x", "y")) %>%
  left_join(province, by = c("x", "y")) %>%
  dplyr::rename(lu =  LU_PA_0_1_repro_res,
                province = province_repro_res) %>%
  filter(province != 8) # EXCLUDE BRUNEI HERE


lu_types = sort(unique(defor_ou$lu))

lookup_lu_types <- data.frame(lu = lu_types, lu_name = c("no PA, no concession", "IUCN 1-3", "IUCN 3-6,others", 
                                                         "other national PAs", "logging concession", "ITP","oil palm concession"),
                              lu_short = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))
lookup_lu_types$lu_name <- factor(lookup_lu_types$lu_name, levels = c( "IUCN 1-3", "IUCN 3-6,others", 
                                                                       "other national PAs", "no PA, no concession",
                                                                       "logging concession", "ITP", "oil palm concession"))
lookup_lu_types$lu_short <- factor(lookup_lu_types$lu_short, levels = c("other", "PA1", "PA2", "PA3", "LC", "ITP", "OPC"))

defor_ou <- left_join(defor_ou, lookup_lu_types, by = "lu")




provinces = sort(unique(defor_ou$province))

lookup_provinces <- data.frame(province = provinces, province_name = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                       "Central Kal", "East Kal","North Kal" ),
                               province_short = c("Sab", "Saw", "WK", "SK", "CK", "EK", "NK"))


lookup_provinces$province_name <- factor(lookup_provinces$province_name, levels = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                                    "Central Kal", "East Kal","North Kal" ))
lookup_provinces$province_short <- factor(lookup_provinces$province_short, levels = c("Sab", "Saw", "WK", "SK", "CK", "EK", "NK"))

defor_ou <- defor_ou %>%
  left_join(lookup_provinces, by = "province")

defor_ou$country <- NA
defor_ou[defor_ou$province_name %in% c("Sarawak", "Sabah"), "country"] <- "Malaysia"
defor_ou[!(defor_ou$province_name %in% c("Sarawak", "Sabah")), "country"] <- "Indonesia"


# how many ou in which category in which province

# summe muss ich durch summe aller ou's in dem staat teilen

ou_sum_lookup <- defor_ou %>%
  filter(bi_class != 0)%>%
  group_by(province_name)%>%
  summarize(sum_province_ou = sum(ou_dens),
            prov_area = n())

defor_ou_prov <- defor_ou %>%
  filter(bi_class != 0)%>%
  group_by(bi_class, province_name) %>%
  summarize(sum_ou = sum(ou_dens),
            class_area = n())%>%
  left_join(ou_sum_lookup, by = "province_name") %>%
  mutate(perc_ou = sum_ou * 100/ sum_province_ou,
         perc_area = class_area * 100 / prov_area)%>%
  filter(!is.na(province_name))


defor_ou_prov$bi_class <- as.factor(defor_ou_prov$bi_class)
defor_ou_prov$bi_class <- factor(defor_ou_prov$bi_class,levels = c("1","2", "3"))


# barchart with provinces and 3 colors 

defor_ou_prov <- defor_ou_prov %>%
  filter(! province_name %in% c("South Kal", "North Kal"))



pdf("~/Filzbach Examples/workspace/ou_dens_deforest_prov_perc_ou_3_class_together_pie.pdf", width = 0, height = 0, paper = "a4r")
ggplot(defor_ou_prov, aes(y= perc_ou, x = 1/2, fill = bi_class)) +  
  geom_bar(position = "fill", stat = "identity")+
  coord_polar("y")+
  facet_wrap(~province_name)+
  geom_bar(, stat = "identity")+
  scale_fill_manual(values = color_scheme)+
  theme_bw()+
  # xlab("% orangutans") +
  #  ylab("provinces") +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    axis.title=element_text(size = 18, face = "bold"),
    axis.ticks.y = element_blank(),
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,0.2,0.1,0.1),"cm"))

dev.off()

write.csv(defor_ou_prov, "~/Filzbach Examples/workspace/ou_dens_deforest_prov_perc_ou_3_class_together_pie.csv", row.names = F)


SAB_SAW_3 <- filter(defor_ou_prov, province_name %in% c("Sabah", "Sarawak") & bi_class %in% c(3)) %>%
  group_by(province_name) %>%
  summarize(perc_ou = round(sum(perc_ou)))

SAB_SAW_1 <- filter(defor_ou_prov, province_name %in% c("Sabah", "Sarawak") & bi_class %in% c(1)) %>%
  group_by(province_name) %>%
  summarize(perc_ou = round(sum(perc_ou)))

Kali <-  filter(defor_ou_prov, province_name %in% c("West Kal", "Central Kal", "East Kal") & bi_class %in% c(3)) %>%
  group_by(province_name) %>%
  summarize(perc_ou = round(sum(perc_ou)))

Kali_1 <-  filter(defor_ou_prov, province_name %in% c("West Kal", "Central Kal", "East Kal") )%>%
group_by(bi_class) %>%
  summarize(sum = sum(sum_ou))
sum_Kali_1 <- sum(Kali_1$sum)

Kali_1 <- mutate(Kali_1, perc = sum*100/sum_Kali_1)

#lu classes ----

# lump PAs and concessions together
str(defor_ou)
table(defor_ou$lu_name)
defor_ou$lu_name <- as.character(defor_ou$lu_name)

defor_ou[defor_ou$lu_name %in% c( "IUCN 1-3", "IUCN 3-6,others", 
                                  "other national PAs"), "lu_name"] <- "PA"
defor_ou[defor_ou$lu_name %in% c( "ITP", "oil palm concession"), "lu_name"] <- "IP"
defor_ou$lu_name <- as.factor(defor_ou$lu_name)
table(defor_ou$lu_name)

ou_sum_lookup <- defor_ou %>%
  filter(bi_class != 0)%>%
  group_by(lu_name)%>%
  summarize(sum_lu_ou = sum(ou_dens),
            lu_area = n())

# percent area of nondesignated areas
total_area = sum(ou_sum_lookup$lu_area)
perc_area <- ou_sum_lookup %>%
  mutate(perc_of_total_area = lu_area * 100/total_area)
  
  

defor_ou_lu <- defor_ou %>%
  filter(bi_class != 0)%>%
  group_by(bi_class, lu_name) %>%
  summarize(sum_ou = sum(ou_dens),
            class_area = n())%>%
  left_join(ou_sum_lookup, by = "lu_name") %>%
  mutate(perc_ou = sum_ou * 100/ sum_lu_ou,
         perc_area = class_area * 100 / lu_area)%>%
  filter(!is.na(lu_name))


defor_ou_lu$bi_class <- as.factor(defor_ou_lu$bi_class)
defor_ou_lu$bi_class <- factor(defor_ou_lu$bi_class,levels = c("1","2", "3"))


# barchart with lus and 3 colors 
pdf("~/Filzbach Examples/workspace/ou_dens_deforest_lu_perc_ou_3_class_together_pie.pdf", width = 0, height = 0, paper = "a4r")
ggplot(defor_ou_lu, aes(y= perc_ou, x = 1/2, fill = bi_class)) +  
  geom_bar(position = "fill", stat = "identity")+
  coord_polar("y")+
  facet_wrap(~lu_name)+
  geom_bar(, stat = "identity")+
  scale_fill_manual(values = color_scheme)+
  theme_bw()+
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    axis.title=element_text(size = 18, face = "bold"),
    axis.ticks.y = element_blank(),
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,0.2,0.1,0.1),"cm"))

dev.off()

total_nr_ou = sum(defor_ou_lu$sum_ou)

lu_perc_low <- filter(defor_ou_lu, bi_class %in% c(1)) %>%
  group_by(lu_name) %>%
  summarize(sum_perc = round(sum(perc_ou)))


lu_perc_medium<- filter(defor_ou_lu, bi_class %in% c(2)) %>%
  group_by(lu_name) %>%
  summarize(sum_perc = round(sum(perc_ou)), 
            sum_ou_in_class = sum(sum_ou),
            of_total=  round(sum_ou_in_class * 100 / total_nr_ou))




lu_perc_high <- filter(defor_ou_lu, bi_class %in% c(3)) %>%
  group_by(lu_name) %>%
  summarize(sum_perc = round(sum(perc_ou)), 
            sum_ou_in_class = sum(sum_ou),
            of_total=  round(sum_ou_in_class * 100 / total_nr_ou))




# calculate combined percent in class IP and other
defor_ou[defor_ou$lu_short %in% c("ITP", "OPC", "other"), "lump_name"] <- "IP_other"
defor_ou[!defor_ou$lu_short %in% c("ITP", "OPC", "other"), "lump_name"] <- "better"
ou_sum_lookup[ou_sum_lookup$lu_name %in% c("IP", "no PA, no concession"), "lump_name"] <- "IP_other"
ou_sum_lookup[!ou_sum_lookup$lu_name %in% c("IP", "no PA, no concession"), "lump_name"] <- "better"

ou_sum_lookup <- ou_sum_lookup %>%
  group_by(lump_name)%>%
  summarize(sum_lu_ou = sum(sum_lu_ou),
            lu_area = sum(lu_area))

defor_ou_lu_lumped <- defor_ou %>%
  filter(bi_class != 0)%>%
  group_by(bi_class, lump_name) %>%
  summarize(sum_ou = sum(ou_dens),
            class_area = n())%>%
  left_join(ou_sum_lookup, by = "lump_name") %>%
  mutate(perc_ou = sum_ou * 100/ sum_lu_ou,
         perc_area = class_area * 100 / lu_area)
