
# -*- coding: utf-8 -*-
"""
Created on Wed Apr 18 13:54:10 2018

@author: mv39zilo
"""

# converting the layers for the deforestation model
# all layers must be co-registered 
# with all layers in file with 

# Forest layers
# I use David Gaveau's most recent layer

# 1
# we use 5 years intervals (0)
# this is for 2012 - 2016 --> 1 forest 
# deforestation 2001 - 2012
# and for forest 2 2012-2016 = 0

import numpy as np
import os
from osgeo import ogr
import shutil
from glob import glob

import MacPyver as mp

out_path = (r'~\Filzbach Examples\workspace\raw')

out_path_final = (r'~\Filzbach Examples\workspace\repro_res')

out_path_asci = (r'~\Filzbach Examples\workspace\asci')


forest_path = (r'~\Filzbach Examples\workspace\data\annual_deforestation_of_natural_forest_for_2000_2016_margono_hansen_elim1ha_utm50n_04DEC2017.tif')

# this is categorical - so nearest neighbor reasampling
os.system("""gdalwarp -r "near" -overwrite -t_srs "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_def" -te -1751798.359 1267454.241 -629798.359 2560454.241 -ts 1122 1293 """ + forest_path + " " + out_path + "\\forest_repro_res.tif")

# this is the reference for exporting all the files
ref_path = (out_path + "\\forest_repro_res.tif")

forest = mp.raster.tiff.read_tif( out_path + "\\forest_repro_res.tif", 1)

# three layers
# one is  0 = previous deforestation, 1= forest, -9999 = sea, non-forest vegetation. This is observed 
#  observed deforestation, -9999 = not deforested or not considered, 1 = forest converted to non-forest 

# layer 1 --> forest in 2015 
forest_1 = forest
forest_1 = np.where(((forest_1 > 17) | (forest_1 == 0)), -9999, forest_1)
forest_1 = np.where((forest_1 <= 11) & (forest_1 != -9999), 0, forest_1)
forest_1 = np.where(((forest_1 >= 12) & (forest_1 <= 17)), 1, forest_1)

np.unique(forest_1)

mp.raster.tiff.write_tif(ref_path, 
                         out_path_final + '/forest_2012_16_repro_res.tif', forest_1, nodata=-9999, option='compress=deflate')


# layer 2 (deforestation in 2015)
forest_2 = forest
forest_2 = np.where((forest_2 >= 12) & (forest_2 < 17), 1, -9999)

mp.raster.tiff.write_tif(ref_path,
out_path_final + '/deforestation_2012_16_repro_res.tif', forest_2, nodata=-9999, option='compress=deflate')


# layer for plotting figures: forest in 2011, because this is where the first projection starts from

forest_3 = forest
forest_3 = np.where(((forest_3 > 17) | (forest_3 == 0)), -9999, forest_3)
forest_3 = np.where((forest_3 <= 11) & (forest_3 != -9999), 0, forest_3)
forest_3 = np.where(forest_3 >= 12, 1, forest_3)

np.unique(forest_3)

mp.raster.tiff.write_tif(ref_path, 
                         out_path_final + '/forest_2012_repro_res.tif', forest_3, nodata=-9999, option='compress=deflate')


forest_4 = forest
forest_4 = np.where(((forest_4 > 17) | (forest_4 == 0)), -9999, forest_4)
forest_4 = np.where((forest_4 <= 16) & (forest_4 != -9999), 0, forest_4)
forest_4 = np.where(forest_4 >= 17, 1, forest_4)

np.unique(forest_4)

mp.raster.tiff.write_tif(ref_path, 
                         out_path_final + '/forest_2017_repro_res.tif', forest_4, nodata=-9999, option='compress=deflate')




# all layers are clipped with the forest layer is 1 or 0, so we only have data there, where there is forest

infile = r'~\\Filzbach Examples\\workspace\\raw\\fire_density.tif'

fire_dens =  mp.raster.tiff.read_tif(infile, 1)


fire_dens = np.where(forest_1==-9999, -9999, fire_dens)


np.sum(fire_dens)
np.sum(fire_dens)

ref_path = (out_path + "\\forest_repro_res.tif")

mp.raster.tiff.write_tif(infile, out_path_final + "\\fire_dens_repro_res.tif",
                         fire_dens, nodata=-9999, option='compress=deflate')

# PRotected areas
# 1. make the categories into numbers and make the new classes

# 3 categories
# 0, 1, 2 for no protection, high protection, low protection



infile = r'~\Filzbach Examples\workspace\model_input\raw\PA_Borneo_repro_3_classes.tif'
PA_3 = mp.raster.tiff.read_tif(infile, 1)

PA_3 = np.where((forest_1 != 1), -9999, PA_3)
PA_3 = np.where((forest_1 == 1) & (PA_3 == 0), 0, PA_3)
PA_3 = np.where((forest_1 == 1) & (PA_3 ==1 ), 1, PA_3)
PA_3 = np.where((forest_1 == 1) & (PA_3 ==2 ), 2, PA_3)

mp.raster.tiff.write_tif(infile, out_path_final + "\\PA_Borneo_3_classes_repro_res.tif",
                         PA_3, nodata=-9999, option='compress=deflate')
                         
                         
                         
## rivers distance
# can we think about rasterizing them at a much higher resolution, then do the distance at 
# 1k so that it isnt so rough

infile = out_path + "/rivers_1km_distance.tif"
# no data value

river_distance = mp.raster.tiff.read_tif(infile, 1)
river_distance = np.where(forest_1 == -9999, -9999, river_distance)

mp.raster.tiff.write_tif(infile, out_path_final + "\\rivers_1km_distance_repro_res.tif",
                         river_distance, nodata=-9999, option='compress=deflate')


infile = out_path_final + "/roads_1km_distance.tif"
# no data value

road_distance = mp.raster.tiff.read_tif(infile, 1)
road_distance = np.where(forest_1 == -9999, -9999, road_distance)

mp.raster.tiff.write_tif(infile, out_path_final + "\\road_1km_distance_repro_res.tif",
                         road_distance, nodata=-9999, option='compress=deflate')





# state
# here important that areas outside have to be -9999
# provinces
province_path = r'~\Filzbach Examples\workspace\State\Borneo_province_repro_res.tif'

province = mp.raster.tiff.read_tif(province_path, 1)
# give all provinces a number

province = np.where((forest_1 == -9999), -9999, province)

# 1 = 8
province = np.where((province >= 1) & (province <= 4), 80, province)



# 10= 1
province = np.where(province == 10, 1, province)

# 11 = 2
province = np.where(province == 11, 2, province)

# 13 = 3
province = np.where(province == 13, 3, province)

# 14 = 4
province = np.where(province == 14, 4, province)

# 15 = 5
province = np.where(province == 15, 5, province)

# 16= 6
province = np.where(province == 16, 6, province)

#17= 7
province = np.where(province == 17, 7, province)

province = np.where((province == 80), province / 10, province)

province = np.where(province == 0, -9999, province)

mp.raster.tiff.write_tif(ref_path,
out_path_final + '/province_repro_res.tif', province, nodata=-9999, dtype = 4, option='compress=deflate')

# countries
country_path = r'~\Filzbach Examples\workspace\State\Borneo_country_repro_res.tif'

country = mp.raster.tiff.read_tif(country_path, 1)

country = np.where(country == 0, -9999, country)
country = np.where(country == 106, 1, country)
country = np.where(country == 136, 2, country)
country = np.where(country == 36, 3, country)

country = np.where(forest_1 == -9999, -9999, country)

mp.raster.tiff.write_tif(country_path,
out_path_final + '/country_repro_res.tif',country, nodata=-9999, option='compress=deflate')

# peat or mineral soil
# peat = 0
# mineral soil = 1
# rest = -999



LC_path = out_path + "\\landcover_repro_res.tif"

LC = mp.raster.tiff.read_tif(LC_path, 1)

LC= np.where(forest_1==-9999, -9999, LC)

mp.raster.tiff.write_tif(out_path + "\\landcover_repro_res.tif",
out_path_final + '/landcover_repro_res.tif', LC, nodata=-9999, option='compress=deflate')


# concessions

LU_path = out_path + "\\LU2012_repro.tif"

LU = mp.raster.tiff.read_tif(LU_path, 1)

LU= np.where((forest_1 == -9999), -9999, LU)

LU= np.where((LU != -9999), (LU + 1), LU)
# sequence needs to be from 1 to 5 not 0 to 4


mp.raster.tiff.write_tif(LU_path,
out_path_final + '/LU_repro_res.tif', LU, nodata=-9999, option='compress=deflate')


                         
                         
#pop_dens
# landscan shouldn't be reprojected, not sure if this is the right way, but in fact it is more about
# general patterns and not making calculations with this                         
os.system("""gdalwarp -r "bilinear" -overwrite -t_srs "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_def" -te -1751798.359 1267454.241 -629798.359 2560454.241 -ts 1122 1293 """ + 
    out_path + "\\pop_dens.tif"+ " " + out_path + "\\pop_dens_repro_res_bi.tif")


pop_dens_path = r'~\Filzbach Examples\workspace\model_input\raw\pop_dens_repro_res.tif'
pop_dens = mp.raster.tiff.read_tif(pop_dens_path, 1)
np.unique(pop_dens)
pop_dens = np.where((pop_dens < 0) | (forest_1 == -9999), -9999, pop_dens)

mp.raster.tiff.write_tif(pop_dens_path,
out_path_final + '/pop_dens_repro_res.tif', pop_dens, nodata=-9999, option='compress=deflate')


# dem
# reproject using bilinear
os.system("""gdalwarp -overwrite -r "bilinear" -t_srs "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_def" -te -1751798.359 1267454.241 -629798.359 2560454.241 -ts 1122 1293 """ + 
   "~\Filzbach Examples\workspace\elevation\dem.tif"+ " " + out_path + "\\dem_repro_res_bilinear.tif")

dem_path = r'~\Filzbach Examples\workspace\model_input\raw\dem_repro_res.tif'
dem = mp.raster.tiff.read_tif(dem_path, 1)
np.unique(dem)
dem = np.where((forest_1 == -9999), -9999, dem)

mp.raster.tiff.write_tif(dem_path,
out_path_final + '/dem_repro_res.tif', dem, nodata=-9999, option='compress=deflate')



# Joining layers LU and PA
# I need to extract PA1 , 2 and the community protection category that is on top in LU PA
# then resolve the overlapw ith PA1, 2--> I would say, if it is in PA IUCN, keep this!
# or we could say, if it is a concession, it is not park, and consider what is informed by the country as better

LU_path = out_path_final + "/LU_repro_res.tif"
LU = mp.raster.tiff.read_tif(LU_path, 1)

PA_3_path =  out_path_final + "/PA_Borneo_3_classes_repro_res.tif"

PA_3 = mp.raster.tiff.read_tif(PA_3_path, 1)
                         
                         
# coding
# 1- infrastructure-other , 2- PA_1, 3- PA_2 , 4- PA_3 , 5-logging concession , 6- timber concession , 7-oil-palm concession
# overwrite or not, because LU Is from 2012
new_layer = np.where(LU>2, LU + 2, 0)    
np.unique(new_layer)       
new_layer = np.where(LU == 1, LU, new_layer)      
np.unique(new_layer)
new_layer = np.where((new_layer == 0)  & (LU==2), 4, new_layer)
np.unique(new_layer) 
    
new_layer = np.where((new_layer == 4)  & (PA_3 == 1), 2, new_layer)
np.unique(new_layer) 
new_layer = np.where((new_layer == 4)  & (PA_3 == 2), 3, new_layer)
np.unique(new_layer)              
                      
new_layer = np.where(new_layer == 0, -9999, new_layer)
                         
np.unique(new_layer)                         
                         
mp.raster.tiff.write_tif(PA_3_path,
out_path_final + '/LU_PA_repro_res.tif', new_layer, nodata=-9999, option='compress=deflate')
              
              
# now I am classifying the protected area category I as 0
            
new_layer_2 = np.where(new_layer == 2, 0, new_layer)
new_layer_2 = np.where(new_layer_2 > 2, (new_layer_2 - 1), new_layer_2)    
np.unique(new_layer_2)   

mp.raster.tiff.write_tif(PA_3_path,
out_path_final + '/LU_PA_0_2_repro_res.tif', new_layer_2, nodata=-9999, option='compress=deflate')



# now I am classifying the other/infrastructure/urban as 0

new_layer_3 =  np.where(new_layer > 0, new_layer - 1, new_layer)
np.unique(new_layer_3)
              
              
mp.raster.tiff.write_tif(PA_3_path,
out_path_final + '/LU_PA_0_1_repro_res.tif', new_layer_3, nodata=-9999, option='compress=deflate')


def compare(rast_path_1, rast_path_2):
    rast1_ext = mp.raster.tiff.get_extent(rast_path_1)
    rast2_ext = mp.raster.tiff.get_extent(rast_path_2)
    error= False
    if rast1_ext.px_size != rast2_ext.px_size:
        error = True
    if rast1_ext.columns != rast2_ext.columns:
        error = True
    if rast1_ext.left != rast2_ext.left:
        error = True
    if error:
        return 'files are not matching'
    else:
        print 'alles ist gut'


# reproject to same extent and resolution
## transfer all to asci
inpath = r'~\Filzbach Examples\workspace\model_input\repro_res'
file_list = glob( inpath + '\*.tif')

for file_path in file_list:
    print(file_path)
    compare(ref_path, file_path)

file_names = [os.path.basename(x) for x in file_list]
print(file_names)
for layer in file_list:
    print(layer)    
    file_name = os.path.basename(layer)
    print(file_name)    
    # do a check and compare all rasters to the forest raster

    os.system("""gdal_translate -of "AAIGrid" """ + inpath + "\\" + file_name[:-4] + ".tif " + out_path_asci + "\\" + file_name[:-4] + ".ascii" )

    
    

