# script to produce both observed and predicted deforestation in Borneo

rm(list=ls())
library(tidyverse)
library(foreach)
library(reshape2)

#----------------#
#   OBSERVATION  #
#----------------#
# 1 year
data <- read.csv("~/Filzbach Examples/workspace/deforestation_data.csv")


# deforestation rate
deforestation_data <- data %>%
  dplyr::filter(type == "loss"& lu == "none" & province == "Borneo") %>%
  mutate(year = year + 2000, 
         area_km2 = nr_pixel * resolution^2 / 1000^2)


years <- (unique(deforestation_data$year))
res <- (unique(deforestation_data$resolution))
deforestation_data$similarity <- NA
deforestation_data$divergence <- NA



for (year in years){
  similarity <- deforestation_data[deforestation_data$year == year & 
                                deforestation_data$resolution == 1000, "area_km2"] * 100/
    deforestation_data[deforestation_data$year == year & 
                         deforestation_data$resolution == 30, "area_km2"]
  
  deforestation_data[deforestation_data$year == year  & 
                       deforestation_data$resolution == 1000, "similarity"] <- similarity
  divergence <- deforestation_data[deforestation_data$year == year & 
                                     deforestation_data$resolution == 1000, "area_km2"]-
    deforestation_data[deforestation_data$year == year & 
                         deforestation_data$resolution == 30, "area_km2"]
  deforestation_data[deforestation_data$year == year  & 
                       deforestation_data$resolution == 1000, "divergence"] <- divergence
  
}

deforestation_data[deforestation_data$resolution == 1000, "res_id"] <- "1 x 1 km"
deforestation_data[deforestation_data$resolution == 30, "res_id"] <- "30 x 30 m"

pdf("~/Filzbach Examples/workspace/forest_area_resolution.pdf", paper = "a4r", width = 0, height = 0)
ggplot(data = deforestation_data, aes(x = year, y = area_km2, fill = as.factor(res_id)))+
  # geom_point()+
  # geom_line()+
  geom_bar(stat = "identity", position = "dodge")+
  theme_bw() +
  xlab("year") +
  ylab(as.expression(bquote("yearly tree cover loss in" ~ km^2 ~ ""))) +
  scale_x_continuous(breaks = c(2001:2016),
                     labels = c(2001, rep("", times = 4) ,2006, rep("", times = 4), 2011, rep("", times = 4),
                                2016))+
  scale_fill_manual(values = c("grey25", "grey79"))+
  guides(fill=guide_legend(title="resolution"))+                     
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14, face = "bold"),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    axis.ticks.y = element_blank(),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,0.2,0.1,0.1),"cm"))
dev.off()
