# script to produce both observed and predicted deforestation in Borneo

rm(list=ls())
library(tidyverse)
library(foreach)
library(reshape2)

options("scipen" = 100, "digits" = 10)


#----------------#
#   OBSERVATION  #
#----------------#
# 1 year
data <- read.csv("~/Filzbach Examples/workspace/deforestation_data.csv")


# deforestation rate
forest_data <- data %>%
  dplyr::filter(type == "loss" & lu == "none" & province != "Borneo", resolution == 1000) %>%
  mutate(year = year + 2000) %>%
  rename(abs_loss = nr_pixel)



provinces = unique(forest_data$province)

lookup_provinces <- data.frame(province = provinces, province_name = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                       "Central Kal", "East Kal","North Kal" ))


lookup_provinces$province_name <- factor(lookup_provinces$province_name, levels = c("Sabah", "Sarawak", "West Kal", "South Kal",
                                                                                    "Central Kal", "East Kal","North Kal" ))

forest_data_1 <- forest_data %>%
  left_join(lookup_provinces, by = "province") %>%
  mutate(interval_length = 1)





## 5 years
data <- read.csv("~/Filzbach Examples/workspace/deforestation_data_11y_5y.csv")


# provinces
forest_data <- data %>%
  dplyr::filter(type == "loss" & lu == "none" & province != "Borneo")%>%
  rename(abs_loss = nr_pixel,
         year_interval = year)%>%
  mutate(interval_length = NA)


forest_data <- forest_data %>%
  left_join(lookup_provinces, by = "province")

# forest_data$country <- NA
# forest_data[forest_data$province_name %in% c("Sarawak", "Sabah"), "country"] <- "Malaysia"
# forest_data[!(forest_data$province_name %in% c("Sarawak", "Sabah")), "country"] <- "Indonesia"

forest_data[forest_data$year_interval == "2001-2011", "year"] <- mean(c(2001:2011))
forest_data[forest_data$year_interval == "2001-2011", "interval_length"] <- length(c(2001:2011))
forest_data[forest_data$year_interval == "2012-2016", "year"] <- mean(c(2012:2016))
forest_data[forest_data$year_interval == "2012-2016", "interval_length"] <- length(c(2012:2016))

forest_data_obs5 <- forest_data

#------------------#
# Prepare baseline #
#------------------#
baseline <-  data %>%
  dplyr::filter(type == "forest" & year == 2000 & lu == "none" & province != "Borneo")%>%
  dplyr::select(province, forest_area_2000 = nr_pixel)

endline <- data %>%
  dplyr::filter(type == "forest" & year == 2017 & lu == "none" & province != "Borneo")%>%
  dplyr::select(province, forest_area_2017 = nr_pixel)

#------------#
#   FUTURE   #
#------------#
forest_data_5 <- read.csv("O:/Maria_Voigt/deforestation_model/future_deforest/PA_0_1_5yr_I_roads/future_deforestation_ou_5y_prov_lu_I_roads.csv") %>%
  filter(type == "forest_loss",
         province != "Borneo",
         is.na(category)) %>%
  dplyr::select(province:nr_pixel)%>%
  rename(abs_loss =nr_pixel) 

years = unique(forest_data_5$year)


# Provinces

provinces <- unique(forest_data_5$province)

forest_data_5 <- forest_data_5 %>%
  left_join(lookup_provinces, by = "province")



forest_data_5 <- forest_data_5 %>%
  mutate(year_2 = 2014 + year * 5,
         interval_length = 5)

unique(forest_data_5$year_2)




# combine both and have a label that we can use to wrap it with (observed - projected)


forest_data_observed <- forest_data_1 %>%
  mutate(yearly_loss = abs_loss / interval_length) %>%
  left_join(baseline, by = "province")%>%
  mutate(perc_loss = yearly_loss*100/forest_area_2000,
         type = "observation")%>%
  dplyr::select(province_name, year, forest_area_2000, abs_loss, yearly_loss, perc_loss, type ) 


forest_data_5_observed <- forest_data_obs5 %>%
  mutate(yearly_loss = abs_loss / interval_length)%>%
  left_join(baseline, by = "province")%>%
  mutate(type = "observation", 
         perc_loss = yearly_loss*100/forest_area_2000) %>%
  dplyr::select(province_name, year, forest_area_2000, abs_loss, yearly_loss, perc_loss, type ) 



forest_data_5_project <- forest_data_5 %>%
  mutate(yearly_loss = abs_loss / interval_length) %>%
  left_join(baseline, by = "province")%>%
  mutate(type = "projection", 
         perc_loss = yearly_loss*100/forest_area_2000)%>%
  dplyr::select(province_name, year = year_2, abs_loss, yearly_loss, perc_loss, type)




forest_data_proj_ci <- forest_data_5_project %>%
  group_by(province_name, year)%>%
  summarize(
    median = median(perc_loss),
    lower_ci = quantile(perc_loss, probs = 0.025),
    upper_ci = quantile(perc_loss, probs = 0.975)
  )

# this is the overshoot

overshoot<- foreach(province = lookup_provinces$province_name, .combine = 'rbind')%do%{
  divergence <- (forest_data_proj_ci[forest_data_proj_ci$province_name == province &
                        forest_data_proj_ci$year ==2014, "median" ] -
    forest_data_5_observed[forest_data_5_observed$province_name == province &
                           forest_data_5_observed$year == 2014, "perc_loss"])
 return(c(as.character(province), divergence) )
}

overshoot <- data.frame(province = lookup_provinces$province_name, median = unlist(overshoot[, 2]))
round(min(overshoot$median), 1)
round(max(overshoot$median), 1)
# difference Sabah

forest_data_5_observed[forest_data_5_observed$province_name == "Sabah" & forest_data_5_observed$year == 2014, "yearly_loss"] - 
  forest_data_5_observed[forest_data_5_observed$province_name == "Sabah" & forest_data_5_observed$year == 2006, "yearly_loss"]
  
forest_data_5_observed[forest_data_5_observed$province_name == "Sabah" & forest_data_5_observed$year == 2014, "perc_loss"] - 
  forest_data_5_observed[forest_data_5_observed$province_name == "Sabah" & forest_data_5_observed$year == 2006, "perc_loss"]



forest_data <- rbind(forest_data_observed, forest_data_5_observed)


# we want a barchart that extends until 2031
# which plots first the five year observation, then the one year on top

pdf("~/Filzbach Examples/workspace/proj_observ_forest_loss_bar_roads_11_5_average_perc.pdf", paper = "a4r", width = 0, height = 0)
ggplot()+
  geom_bar(data = forest_data_proj_ci, 
           aes(x = year, y = median), color = "blue", fill = "white", stat = "identity", position = "dodge")+
  geom_errorbar(data = forest_data_proj_ci, 
                aes(ymin=lower_ci, ymax=upper_ci, x = year), size = 0.6, width=1.2)+
  geom_bar(data = forest_data_5_observed,
           aes(x = year, y = perc_loss), color = "red", fill = "grey", alpha = 0.4, size = 0.5, stat = "identity", position = "dodge")+
  geom_point(data = forest_data_observed,
             aes(x = year, y = perc_loss), color = "black")+
  geom_line(data = forest_data_observed,
            aes(x = year, y = perc_loss), color = "red", linetype = "dashed", size = 0.5)+
  #  scale_x_continuous(breaks = c(2001,2006, 2011, 2016, 2021, 2026, 2031), labels = c(2001, 2006,2011, 2016, 2021, 2026, 2031))+
  scale_x_continuous(breaks = c(2001:2031),
                     labels = c(2001,rep("", times = 9),2011,2012,rep("", times = 3),
                                2016,2017,rep("", times = 3),
                                2021,2022, rep("", times = 3), 2026,2027,rep("", times = 3), 2031))+
  scale_y_continuous(limits = c(0, 3))+
  facet_wrap(~province_name, scales = "free")+
  theme_bw() +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text.y = element_text(size = 12, face="bold"),
    axis.text.x=element_text(size = 12, face="bold", angle = 90, hjust=0.5,vjust=0.2),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=14),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.1,0.1,0.1,0.1),"cm"))
dev.off()



# comparison of forest area
baseline <- mutate(baseline, year = 2000)%>%
  rename(forest_area = forest_area_2000)
endline <- mutate(endline, year = 2017) %>%
  rename(forest_area = forest_area_2017)

# to know where we are in the future, we need to use forest 2017 and deduce the summed loss for each of the 100
# calculate mean and then per year 


# continue here with using i
forest_area_5 <- read.csv("~/Filzbach Examples/workspace/future_deforestation_ou_5y_prov_lu_I_roads.csv") %>%
  filter(type == "forest_loss",
         province != "Borneo",
         is.na(category)) %>%
  dplyr::select(i, province:nr_pixel)%>%
  rename(abs_loss =nr_pixel) 

futureline <- forest_area_5 %>%
  filter(year != 0) %>%
  # loss over all years for each iteration
  group_by(province, i)%>%
  summarize(sum = sum(abs_loss))%>%
  #calculate final area
  left_join(endline, by = "province") %>%
  mutate(final_area = forest_area - sum,
         percentage_area_loss = round(100- (final_area * 100 / forest_area) , 0))%>%
  group_by(province)%>%
  summarize(
    forest_area = median(final_area),
    lower_ci_area = quantile(final_area, probs = 0.025),
    upper_ci_area = quantile(final_area, probs = 0.975),
    median_percent_loss = median(percentage_area_loss),
    lower_ci_percent_loss = quantile(percentage_area_loss, probs = 0.025),
    upper_ci_percent_loss = quantile(percentage_area_loss, probs = 0.975)
  )%>%
  mutate(year = 2031) 

futureline_ci <- futureline %>%
  dplyr::select(province, year, lower_ci_area, upper_ci_area) %>%
  #melt(id = c("province", "year")) %>%
  left_join(lookup_provinces, by ="province")

futureline_area <- futureline %>%
  dplyr::select(province, forest_area, year)


forest_area <- rbind(baseline, endline)%>%
  rbind(., futureline_area) %>%
  melt(id = c("province", "year")) %>%
  left_join(lookup_provinces, by ="province")

pdf("~/Filzbach Examples/workspace/proj_observ_forest_roads.pdf", paper = "a4r", width = 0, height = 0)
ggplot()+
  geom_bar(data = forest_area, 
           aes(x = province_name, y = value, fill = as.factor(year)), stat = "identity", position = "dodge")+
  geom_errorbar(data = futureline_ci, 
                aes(ymin=lower_ci_area, ymax=upper_ci_area, x = province_name),
                size = 1, width=0.2)+ 
  scale_fill_manual(values=alpha(c("darkred", "red", "blue"), 0.5)) +
  scale_y_continuous(labels=function(x) format(x, big.mark = ",", scientific = FALSE))+
  theme_bw() +
  xlab("year") +
  ylab(as.expression(bquote("forest cover in " ~ km^2 ~ ""))) +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 14),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=14),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold")) +
  theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
dev.off()


# how much % of the area of a state is forested in 2000
# load province lookup, merge with province lookup containing names
# calculate percents

province_area <- read.csv("~/Filzbach Examples/workspace/province_area_lookup.csv", stringsAsFactors = F) %>%
  mutate(province = as.factor(province)) %>%
 # left_join(lookup_provinces, by = "province") %>%
  rename(area = nr_pixel) %>%
  filter(province != 8 & province != 0) %>% # Brunei
  mutate(year = 2000, 
         type = "area")

ggplot(province_area, aes(x = province, y = area))+
  geom_bar(stat = "identity")
# # add this into the plot
# 


forest_area <- rbind(baseline, endline)%>%
  rbind(., futureline_area) %>%
  rename(area = forest_area)%>%
  mutate(type = "forest")%>%
  rbind(., province_area) %>%
  mutate(id = paste0(type, "_", year)) %>%
  dplyr::select(province, id, area) %>%
 # melt(id = c("province", "id")) %>%
  left_join(lookup_provinces, by ="province") 



# construct a proper table around this
# province, area, forest_cover in 2000, percent forest cover in 2000 of area, forest in 2017, 
# forest in 2031, percent forest in 31 of 2017 (loss from 17 - 31)
province_area <- read.csv("~/Filzbach Examples/workspace/province_area_lookup.csv", stringsAsFactors = F) %>%
  rename(area = nr_pixel)  %>%
  filter(province %in% c(1:7)) %>%
  mutate(province = as.factor(province))%>%
  left_join(baseline[ , c("province", "forest_area")], by = "province")%>%
  rename(forest_area_2000 = forest_area) %>%
  left_join(endline[ , c("province", "forest_area")], by = "province")%>%
  rename(forest_area_2017 = forest_area) %>%
  left_join(futureline[ , c("province", "forest_area")], by = "province")%>%
  rename(forest_area_2031 = forest_area) %>%
  left_join(futureline, by = "province")%>%
  dplyr::select(-year, -forest_area)%>%
# % forest cover in 2000 from total area
  mutate(perc_cover_with_forest_2000 = round(forest_area_2000*100/area, 0),
         perc_cover_with_forest_2017 = round(forest_area_2017*100/area, 0))%>%
  left_join(lookup_provinces, by = "province")

# % forest cover loss into future (based on all 100 values)
# here you should actually use the raw values to calculate the percent decline 
  

ggplot()+
  geom_bar(data = forest_area, 
           aes(x = province_name, y = area, fill = as.factor(id)), stat = "identity", position = "dodge") + 
  geom_label(data = province_area, aes(x = province_name, y =100000, label = round(median_percent_loss, 0)))

round(province_area$median_percent_loss - province_area$lower_ci_percent_loss,0)
round(province_area$upper_ci_percent_loss - province_area$median_percent_loss, 0)

# export in decimal separated notation
province_area_out <- province_area %>%
  dplyr::select(province_name, area:forest_area_2000,perc_cover_with_forest_2000,forest_area_2017,
                perc_cover_with_forest_2017, 
                forest_area_2031:upper_ci_percent_loss) 


for (name in names(province_area_out)[c(2,3, 5, 7:9)]){
  province_area_out[, name] <- format(round(province_area_out[ , name], 0), big.mark = ",")
}
  
for (name in names(province_area_out)[c(4, 6, 10:12)]){
  province_area_out[, name] <- round(province_area_out[ , name],0)
}


write.csv(province_area_out, "~/Filzbach Examples/workspace/overview_table_fig_2.csv", row.names = F)
