# 
# script to validate the future deforestation
# by checking perfect match, omission and comission errors in focal and surrounding pixels 
# we can only do this for years for which we have observations
# 2001:2016
# first only look at the respective year, later also the years prior ?
# first 2015, 2016

rm(list=ls())
library(tidyverse)
library(maptools)
library(raster)
library(reshape)
library(foreach)
library(doParallel)

nr_cores <- detectCores() /2
cl <- makeCluster(nr_cores)

registerDoParallel(cl)

inpath <- "~/Filzbach Examples/workspace"
crs_aea <- "+proj=aea +lat_1=7 +lat_2=-32 +lat_0=-15 +lon_0=125 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"

# for each iteration
# we have to use the deforestation as an observation not the forest!!!



# load preddef of year and iteration
year_0 <- as.data.frame(raster("~/Filzbach Examples/workspace/deforestation_2012_16_repro_res.tif"), xy = T)
year = 0


validation_table_yr_0 <- foreach (i = 0:99, .combine = rbind, .packages= c("maptools", "raster","tidyverse" ))%dopar%{
                   
#test <- foreach (i = 0:9, .combine = rbind, .packages= c("maptools", "raster","tidyverse" ))%dopar%{
pred <- readAsciiGrid(file.path(inpath, paste0("preddef_i", i, "_", year, "yr.asc")))
pred_join <- as.data.frame(pred, xy= T)
names(pred_join) <- c("pred", "x", "y")

join_layers <- year_0 %>%
  right_join(pred_join, by = c("x", "y"))
names(join_layers) <- c("x", "y", "obs_deforest", "pred")
# here we need a raster     
pred_r <- raster(file.path(inpath, paste0("preddef_i", i, "_", year, "yr.asc")), crs = CRS(crs_aea))

pred_1km <- as.data.frame(focal(pred_r, w=matrix(1, nc=3, nr=3)), xy= T)
pred_5km <- as.data.frame(focal(pred_r,  w=matrix(1, nc=11, nr=11)), xy= T)
pred_10km <- as.data.frame(focal(pred_r, w=matrix(1, nc=21, nr=21)), xy= T)

join_layers <-join_layers %>%
  left_join(pred_1km, by = c("x", "y")) %>%
#  mutate(pred_1km  = layer) %>%
  left_join(pred_5km, by = c("x", "y")) %>%
 # rename(pred_5km = layer) %>%
  left_join(pred_10km, by = c("x", "y"))# %>%
  #rename(pred_10km = layer)

names(join_layers) <- c(names(join_layers)[1:4],"pred_1km", "pred_5km", "pred_10km")
join_layers <- join_layers[!is.na(join_layers$obs_deforest), ]

join_layers$perfect_match <- join_layers$obs_deforest == join_layers$pred
join_layers$match_1km <-ifelse(join_layers$obs_deforest == 1 & join_layers$pred_1km > 0 , T, F)
join_layers$match_5km<-ifelse(join_layers$obs_deforest == 1 & join_layers$pred_5km > 0 , T, F)
join_layers$match_10km<-ifelse(join_layers$obs_deforest == 1 & join_layers$pred_10km > 0 , T, F)

# now we need to spit this out for every iteration for each match one table
#print(summary(join_layers))

result <- c(year, i, ifelse(is.na(sum(join_layers$perfect_match) / nrow(join_layers) * 100),
                      0, sum(join_layers$perfect_match) / nrow(join_layers)),
            sum(join_layers$match_1km) / nrow(join_layers) * 100,
            sum(join_layers$match_5km) / nrow(join_layers) * 100,
            sum(join_layers$match_10km) / nrow(join_layers) * 100)
return(result)
}

validation_table <- rbind(as.data.frame(validation_table_yr_0))#, as.data.frame(validation_table_yr_1))
names(validation_table) <- c("year", "i", "0 km", "1 km", "5 km", "10 km")

validation_table_m <- melt(validation_table, id.vars = c("year", "i"))%>%
  mutate(variable = as.numeric(sub( " km", "", variable )))


pdf("~/Filzbach Examples/workspace/validation.pdf", paper = "a4r", width = 0, height = 0)
ggplot(data = validation_table_m, aes(x = as.factor(variable), y = value), color = "black", fill = "grey") + 
         geom_boxplot(size = 1, outlier.size = 2, notchwidth = 0.5)+
  theme_bw()+
  xlab("neighborhood ") +
  ylab("% match observed & projected tree cover loss") +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    axis.text=element_text(size = 16, face = "bold"),
    # axis.text.x = element_text(angle = 60, hjust = 1),
    axis.title=element_text(size = 18, face = "bold"),
    #legend.title=element_text(size=18, face = "bold") ,
    legend.title=element_blank(),
    legend.text=element_text(size=15),
    legend.key.height=unit(0.8,"cm"),
    strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
    strip.text = element_text(size = 16, face="bold"))+
theme(plot.margin = unit(c(0.2,-0.2,0.1,0.1),"cm"))
  dev.off()

write.csv(validation_table, "~/Filzbach Examples/workspace/validation_overlap.csv", row.names = F)



sumprob_path <- "~/Filzbach Examples/workspace/sumprob2012_2016.asc"

pred <- readAsciiGrid(file.path(sumprob_path))
pred_join <- as.data.frame(pred, xy= T)
names(pred_join) <- c("pred", "x", "y")

pred_join$x <- round(pred_join$x)
pred_join$y <- round(pred_join$y)
year_0$y <- round(year_0$y)
year_0$x <- round(year_0$x)

test <- left_join(year_0, pred_join, by = c("x", "y"))

boxplot(test$pred~ test$deforestation_2012_16_repro_res)
                